<?php
/**
 * The main class with the entry point to the whole application. This class
 * "emulates" Java(tm)'s entry point call. Additionally it covers local
 * variables from outside access to prevent possible attacks on uninitialized
 * local variables.
 *
 * But good little boys and girls would always initialize their variables... ;-)
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class ApplicationEntryPoint {
	/**
	 * The instances we want to remove after all is done
	 *
	 * @return	void
	 */
	private static $instances = array (
		'cfg',	// The configuration system
		'loader',	// The class loader system
		'debug',  // Debug output
		'db',     // Database layer
		'io',     // Base I/O system (local file [or network])
		'engine', // Template engine ( for ApplicationEntryPoint::app_die() )
		'lang',   // Language sub-system
		'app',    // The ApplicationHelper instance
	);

	/**
	 * The application's emergency exit
	 *
	 * @param		$message	The optional message we shall output on exit
	 * @return	void
	 */
	public static function app_die ($message = "") {
		// Is a message set?
		if (empty($message)) {
			// No message provided
			$message = "No message provided!";
		}

		// Get some instances
		$tpl = FrameworkConfiguration::getInstance()->readConfig("tpl_engine");
		$lang = LanguageSystem::getInstance();
		$io = FileIOHandler::getInstance();

		// Is the template engine loaded?
		if ((class_exists($tpl)) && (is_object($lang)) && (is_object($io))) {
			// Use the template engine for putting out (nicer look) the message
			try {
				$eval = sprintf("$tplEngine = %s::create%s(\"%s%s\", LanguageSystem::getInstance(), FileIOHandler::getInstance());",
					FrameworkConfiguration::getInstance()->readConfig("tpl_engine"),
					FrameworkConfiguration::getInstance()->readConfig("tpl_engine"),
					PATH,
					FrameworkConfiguration::getInstance()->readConfig("tpl_base_path")
				);
				eval($eval);
			} catch (BasePathIsEmptyException $e) {
				die(sprintf("[Main:] Die Template-Engine konnte nicht initialisieren. Grund: <strong>%s</strong>",
					$e->getMessage()
				));
			} catch (InvalidBasePathStringException $e) {
				die(sprintf("[Main:] Die Template-Engine konnte nicht initialisieren. Grund: <strong>%s</strong>",
					$e->getMessage()
				));
			} catch (BasePathIsNoDirectoryException $e) {
				die(sprintf("[Main:] Die Template-Engine konnte nicht initialisieren. Grund: <strong>%s</strong>",
					$e->getMessage()
				));
			} catch (BasePathReadProtectedException $e) {
				die(sprintf("[Main:] Die Template-Engine konnte nicht initialisieren. Grund: <strong>%s</strong>",
					$e->getMessage()
				));
			}

			// Assign message
			$tplEngine->assignVariable("message", $message);

			// Load the template
			$tplEngine->loadCodeTemplate("emergency_exit");

			// Compile the template
			$tplEngine->compileTemplate();

			// Compile all variables
			$tplEngine->compileVariables();

			// Output all
			$tplEngine->output();

			// Good bye...
			exit();
		} else {
			// Output message and die
			die(sprintf("[Main:] Emergency exit reached: <strong>%s</strong>",
				$message
			));
		}
	}

	/**
	 * The application's main entry point. This class isolates some local
	 * variables which shall not become visible to outside because of security
	 * concerns. We are doing this here to "emulate" the well-known entry
	 * point in Java(tm).
	 *
	 * @return	void
	 */
	public static function main () {
		// Some non-global common arrays we need...
		global $_SERVER;

		// Load config file
		require(dirname(__FILE__) . "/inc/config.php");

		// Load all include files
		require(PATH . "inc/includes.php");

		// Load all framework classes
		require(PATH . "inc/classes.php");

		// Include the application selector
		require(PATH . "inc/selector.php");

	} // END - main()

} // END - class

// Do not remove the following line:
ApplicationEntryPoint::main();

// [EOF]
?>
